@@ -1,5 +1,5 @@
 # thoth-common
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,3 +27,7 @@ class NotFoundException(ThothCommonException):
 
 class ConfigurationError(ThothCommonException):
     """Raised on miss-configuration issues."""
+
+
+class WorkflowError(ThothCommonException):
+    """Raised on workflow related issues."""
