@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-common
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,11 +20,13 @@
 import json
 import datetime
 
+from typing import Any
+
 
 class SafeJSONEncoder(json.JSONEncoder):
     """Convert objects to JSON, safely."""
 
-    def default(self, o):
+    def default(self, o: Any) -> Any:
         """Convert an object to JSON, safely."""
         if isinstance(o, datetime.datetime):
             return o.isoformat()
